import { useGameStore } from '@/stores/gameStore'
import { watch } from 'vue'
import { useZoneStore } from '@/stores/zoneStore'

export function useCameraControls(scene: Phaser.Scene): any {
  const gameStore = useGameStore()
  const zoneStore = useZoneStore()
  const camera = scene.cameras.main
  
  function onPointerDown(pointer: Phaser.Input.Pointer) {
    if (gameStore.isPlayerDraggingCamera) return
    gameStore.setPlayerDraggingCamera(true)
  }

  function onPointerUp() {
    if (!gameStore.isPlayerDraggingCamera) return
    gameStore.setPlayerDraggingCamera(false)
  }

  watch(
    () => zoneStore.characterLoaded,
    (characterLoaded) => {
      if (!characterLoaded) return
      // scene.cameras.main.startFollow(scene.children.getByName(gameStore.character!.name) as Phaser.GameObjects.Container);
    }
  )

  scene.input.on(Phaser.Input.Events.POINTER_DOWN, onPointerDown)
  scene.input.on(Phaser.Input.Events.POINTER_UP, onPointerUp)

  return {
    camera
  }
}
